@@ -87,6 +87,7 @@ class S3Storage:
         self.bucketname = u.hostname
         self.access_key = u.username or access_key
         self.secret_key = u.password or secret_key
+        self.path= u.path[1:]  # remove first "/"
         self.is_botocore = is_botocore()
         self.acl = acl
         if self.is_botocore:
@@ -119,5 +120,5 @@ class S3Storage:
         with gzip.open(fp, mode='rb') as gz:
             kwargs = {"ACL": self.acl} if self.acl else {}
             self.s3_client.put_object(
-                Bucket=self.bucketname, Key=keyname,ContentEncoding='gzip',ContentType='text/plain', Body=gz, **kwargs
+                Bucket=self.bucketname, Key=self.path+keyname,ContentEncoding='gzip',ContentType='text/plain', Body=gz, **kwargs
             )
